## 3.19.0 (2022-01-10)

Bump protobuf to 3.19.2 (#6879)

## 3.18.3 (2022-01-03)

Add google.protobuf.internal.api_implementation (#6802)

## 3.18.2 (2021-11-27)

Improve stubs for sequence types (#6386)

## 3.18.1 (2021-11-21)

Fix MutableMapping overrides (#6352)

## 3.18.0 (2021-10-13)

Bump protobuf stub to 3.18.1 and mypy-protobuf 3.0.0 (#6157)

* Bump protobuf stub to 3.18.1 and mypy-protobuf 3.0.0

* Fix ConsumeInteger in google/protobuf/text_format.pyi

The arg was removed in protobuf 3.18

## 3.17.5 (2021-10-12)

Add star to all non-0.1 versions (#6146)

